Fechado

  • Autor Autor glopi
  • Data de início Data de início
Tradução em andamento: em alguns minutos este tópico estará em português. Por enquanto, o conteúdo está no original em espanhol. Ver original
Foi útil? Participe da conversa

Com sua conta grátis você pode responder, mandar mensagem privada ao autor e comprar com Saldo retido: o pagamento é liberado quando você recebe o combinado.

Leva 30 segundos · você volta a este tópico ao terminar
SI tienes acceso al ssh tal vez puedas usar la opción atime de find.


Aquí las opciones que te pueden servir.

Inserir CODE, HTML ou PHP:
       -amin n
              File was last accessed n minutes ago.

       -anewer file
              File was last accessed more recently than file was modified.  If
              file is a symbolic link and the -H option or the -L option is in
              effect, the access time of the file it points to is always used.

       -atime n
              File was last accessed n*24 hours ago.  When  find  figures  out
              how  many  24-hour  periods  ago the file was last accessed, any
              fractional part is ignored, so to match -atime +1, a file has to
              have been accessed at least two days ago.

       -cmin n
              File's status was last changed n minutes ago.

       -cnewer file
              File's status was last changed more recently than file was modi‐
              fied.  If file is a symbolic link and the -H option  or  the  -L
              option  is  in  effect,  the  status-change  time of the file it
              points to is always used.

       -ctime n
              File's status was last changed n*24 hours ago.  See the comments
              for -atime to understand how rounding affects the interpretation
              of file status change times.

Si no tienes ssh tal vez puedas hacer un script con shell_exec y guardando la salida en un fichero aparte.

Otra cosa no se me ocurre.
 
Gracias por la rápida respuesta!

He conseguido entrar por ssh y ejecutando la orden los he listado todos:

Inserir CODE, HTML ou PHP:
find . -atime +28 -name "*.php" > ficheros.txt
y
Inserir CODE, HTML ou PHP:
find . -name "*.php" > ficheros2.txt

Comparando las diferencias entre los dos ficheros he podido afinar un poco más. Ahora a comprobar uno a uno la validez de los resultados.

Repito, gracias y un saludo 😛8:
 

Tópicos similares

SEOnelly
Respostas
1
Visitas
54
elalaxos
E
SEOnelly
Respostas
2
Visitas
62
♠︎—͟͞͞ 𝙅𝘉𝐑𝙕②₃ᛕ °
♠︎—͟͞͞ 𝙅𝘉𝐑𝙕②₃ᛕ °
SEOnelly
Respostas
0
Visitas
89
SEOnelly
SEOnelly
T
Ofereço-me Tema Cerrado
Respostas
5
Visitas
156
LONEWOLFOK
LONEWOLFOK
SEOnelly
  • Trancado
Solicitado ...fechado
Respostas
2
Visitas
142
Datareview
Datareview
Voltar
Topo